package com.cool.bang.modules.business.domain;

import com.cool.bang.common.base.BaseDomain;
import com.cool.bang.common.constant.enums.StatusType;
import com.cool.bang.modules.system.domain.po.Resource;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;
import java.util.List;

/**
 * 小区门店信息
 *
 * @author Sy
 * 2024-10-22 09:08
 */
public class LpbCommunity extends BaseDomain {

    private static final long serialVersionUID = 1L;

    private Long id;

    /**
     * 小区编号
     */
    private String number;

    /**
     * 小区名称
     */
    private String communityName;

    /**
     * 门店名称
     */
    private String storeName;

    /**
     * 小区地址
     */
    private String address;

    /**
     * 开发商
     */
    private String developers;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 纬度
     */
    private String dimension;

    /**
     * 均价 元/月
     */
    private String average;

    /**
     * 最小面积
     */
    private Long minArea;

    /**
     * 最大面积
     */
    private Long maxArea;

    /**
     * 总幢数
     */
    private Long buildingNum;

    /**
     * 总户数
     */
    private Long houseNum;

    /**
     * 起始楼层
     */
    private Long minFloor;

    /**
     * 终止楼层
     */
    private Long maxFloor;

    /**
     * 门店电话
     */
    private String phone;

    /**
     * 物业公司
     */
    private String property;

    /**
     * 物业费用
     */
    private String propertyCost;

    /**
     * 物业电话
     */
    private String propertyPhone;

    /**
     * 车位数量
     */
    private String parkingNum;

    /**
     * 车位配比
     */
    private String parkingRatio;

    /**
     * 供暖方式 1: 集中供暖 2: 暂无供暖
     */
    private Integer heatingType;

    /**
     * 供电方式 1: 民电 2: 商电
     */
    private Integer electricType;

    /**
     * 供水方式 1: 民水 2: 商电
     */
    private Integer waterType;

    /**
     * 介绍标签id 逗号隔开
     */
    private String labelId;

    /**
     * 小区介绍
     */
    private String introduce;

    /**
     * 创建日期
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date createDate;

    /**
     * 更新日期
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date updateDate;

    /**
     * 删除标识 0: 无效 1: 正常
     */
    private Integer delFlag;


    /** 资源 */
    private List<Resource> resources;

    @Override
    public void insertConfigure() {
        super.insertConfigure();
        this.delFlag = StatusType.ENABLE.ordinal();
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public List<Resource> getResources() {
        return resources;
    }

    public void setResources(List<Resource> resources) {
        this.resources = resources;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public String getLabelId() {
        return labelId;
    }

    public void setLabelId(String labelId) {
        this.labelId = labelId;
    }

    public String getCommunityName() {
        return communityName;
    }

    public void setCommunityName(String communityName) {
        this.communityName = communityName;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getDevelopers() {
        return developers;
    }

    public void setDevelopers(String developers) {
        this.developers = developers;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getDimension() {
        return dimension;
    }

    public void setDimension(String dimension) {
        this.dimension = dimension;
    }

    public String getAverage() {
        return average;
    }

    public void setAverage(String average) {
        this.average = average;
    }

    public Long getMinArea() {
        return minArea;
    }

    public void setMinArea(Long minArea) {
        this.minArea = minArea;
    }

    public Long getMaxArea() {
        return maxArea;
    }

    public void setMaxArea(Long maxArea) {
        this.maxArea = maxArea;
    }

    public Long getBuildingNum() {
        return buildingNum;
    }

    public void setBuildingNum(Long buildingNum) {
        this.buildingNum = buildingNum;
    }

    public Long getHouseNum() {
        return houseNum;
    }

    public void setHouseNum(Long houseNum) {
        this.houseNum = houseNum;
    }

    public Long getMinFloor() {
        return minFloor;
    }

    public void setMinFloor(Long minFloor) {
        this.minFloor = minFloor;
    }

    public Long getMaxFloor() {
        return maxFloor;
    }

    public void setMaxFloor(Long maxFloor) {
        this.maxFloor = maxFloor;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }

    public String getPropertyCost() {
        return propertyCost;
    }

    public void setPropertyCost(String propertyCost) {
        this.propertyCost = propertyCost;
    }

    public String getPropertyPhone() {
        return propertyPhone;
    }

    public void setPropertyPhone(String propertyPhone) {
        this.propertyPhone = propertyPhone;
    }

    public String getParkingNum() {
        return parkingNum;
    }

    public void setParkingNum(String parkingNum) {
        this.parkingNum = parkingNum;
    }

    public String getParkingRatio() {
        return parkingRatio;
    }

    public void setParkingRatio(String parkingRatio) {
        this.parkingRatio = parkingRatio;
    }

    public Integer getHeatingType() {
        return heatingType;
    }

    public void setHeatingType(Integer heatingType) {
        this.heatingType = heatingType;
    }

    public Integer getElectricType() {
        return electricType;
    }

    public void setElectricType(Integer electricType) {
        this.electricType = electricType;
    }

    public Integer getWaterType() {
        return waterType;
    }

    public void setWaterType(Integer waterType) {
        this.waterType = waterType;
    }

    public String getIntroduce() {
        return introduce;
    }

    public void setIntroduce(String introduce) {
        this.introduce = introduce;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }
}
