package com.cool.bang.modules.system.controller;

import com.cool.bang.common.base.BaseController;
import com.cool.bang.common.constant.ControllerConstant;
import com.cool.bang.common.constant.enums.OperationType;
import com.cool.bang.common.constant.enums.StatusType;
import com.cool.bang.common.web.request.PageDomain;
import com.cool.bang.common.web.response.Result;
import com.cool.bang.common.web.response.module.ResultTable;
import com.cool.bang.core.annotation.Log;
import com.cool.bang.modules.system.domain.po.Org;
import com.cool.bang.modules.system.service.IOrgService;
import com.github.pagehelper.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 组织机构
 *
 * @author PeiZhi Guo
 * 2022-7-11 11:42
 */
@RestController
@RequestMapping(ControllerConstant.SYSTEM + "org/v1")
public class OrgController extends BaseController {

    private IOrgService orgService;

    @Autowired
    public OrgController(IOrgService orgService) {
        this.orgService  = orgService;
    }

    @GetMapping
    @PreAuthorize("hasPermission('', 'sys:org:main')")
    public ResultTable main(Org param) {
        return treeTable(orgService.list(param));
    }

    @GetMapping("{id}")
    @PreAuthorize("hasPermission('','sys:org:main')")
    public Result get(@PathVariable Long id) {
        return success(orgService.queryById(id));
    }


    @GetMapping("selectTree")
    @PreAuthorize("hasPermission('','sys:org:main')")
    public Result selectTree() {
        return success(orgService.querySelectTree());
    }

    @PostMapping
    @PreAuthorize("hasPermission('','sys:org:add')")
    @Log(operationType = OperationType.INSERT, title = "组织机构")
    public Result save(@RequestBody Org org) {
        if (StringUtils.isBlank(org.getName())) {
            return failure("organization name is not null");
        }
        Org isOrg = orgService.queryByOrgName(org.getName());
        if (isOrg != null) {
            return failure("该组织机构已存在");
        }
        org.setStatus(StatusType.ENABLE.ordinal());
        if (org.getParentId().equals(0L)) {
            org.setLevel(1);
        } else {
            Org parentOrg = orgService.queryById(org.getParentId());
            org.setLevel(parentOrg.getLevel() + 1);
        }
        return decide(orgService.save(org));
    }

    @PutMapping
    @PreAuthorize("hasPermission('','sys:org:edit')")
    @Log(operationType = OperationType.UPDATE , title = "组织机构")
    public Result edit(@RequestBody Org org) {
        if (StringUtils.isBlank(org.getName())) {
            return failure("organization name is not null");
        }
        if (orgService.orgNameUniqueCheck(org.getName(), org.getId())) {
            return failure("该组织机构已存在");
        }
        return decide(orgService.update(org));
    }

    @DeleteMapping("{id}")
    @PreAuthorize("hasPermission('','sys:org:del')")
    @Log(operationType = OperationType.DELETE , title = "组织机构")
    public Result remove(@PathVariable Long id) {
        if (id == null) {
            return failure("organization id is not null");
        }
        if (orgService.queryChildren(id)) {
            return failure("部门下存在子集");
        }
        return decide(orgService.removeById(id));
    }
}
